<?php

// Клавиатура выбора группы

namespace BotKit\Keyboards;

use BotKit\KeyboardButtons\CallbackButton;
use BotKit\Enums\KeyboardButtonColor;
use BotKit\Enums\CallbackType;

use BotKit\Entities;
use BotKit\Common\Database;

class SelectGroupNameKeyboard extends Keyboard {
	#region Драйвер-зависимые свойства
	public $tg_resize=true;
	public $tg_onetime=false;
	public $tg_specific=true;
	public $inline=true;
	#endregion

	public function __construct($intent, int $course, int $offset) {
		// $intent - дополнительное значение для типа обратного вызова
		// Обозначает что необходимо выполнить после того, как будет выбрана
		// специальность

		// $course - курс, выбранный ранее

		// $offset - сдвиг записей для страничного просмотра
		
        $em = Database::getEM();
		$this->layout = [];

        // Искать по году зачисления
        $groups = $em->getRepository(Entities\CollegeGroup::class)->findBy(
			['course_num' => $course]
		);
		$groups_count = count($groups);

		// Генерация разметки
		for ($y = 0; $y < 2; $y++) {
			$row = [];
			for ($x = 0; $x < 3; $x++) {

				$index = $y * 3 + $x + $offset;
				if ($index > $groups_count - 1) {
					// Группы закончились, заканчиваем
					$this->layout[] = $row;
					break 2;
				}
				$group = $groups[$index];
				
				$row[] = new CallbackButton(
					strval($course).' '.$group->getSpec()->getName(),
					CallbackType::SelectGroup,
					KeyboardButtonColor::None,
					['group_id' => $group->getID(), 'intent' => $intent]
				);
			}
			$this->layout[] = $row;
		}

		// Кнопки назад и далее
		$nav_row = [];

		if ($offset - 6 >= 0) {
			// Кнопка назад может работать
			$callback_type = CallbackType::SelectGroupNavigation;
			$color = KeyboardButtonColor::Primary;
		} else {
			// Кнопка назад не может работать
			$callback_type = CallbackType::None;
			$color = KeyboardButtonColor::Secondary;
		}
		$nav_row[] = new CallbackButton(
			"⬅️ Назад",
			$callback_type,
			$color,
			['offset' => $offset - 6, 'intent' => $intent, 'course' => $course]
		);

		if ($offset + 6 < $groups_count) {
			// Кнопка вперёд может работать
			$callback_type = CallbackType::SelectGroupNavigation;
			$color = KeyboardButtonColor::Primary;
		} else {
			// Кнопка вперёд не может работать
			$callback_type = CallbackType::None;
			$color = KeyboardButtonColor::Secondary;
		}
		$nav_row[] = new CallbackButton(
			"Вперёд ➡️",
			$callback_type,
			$color,
			['offset' => $offset + 6, 'intent' => $intent, 'course' => $course]
		);

		$this->layout[] = $nav_row;
	}

	public static bool $cacheable = false;
}